Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java')
-rw-r--r--plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java18
1 files changed, 9 insertions, 9 deletions
diff --git a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
index 71c0d237da..923caec79f 100644
--- a/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
+++ b/plugins/org.eclipse.emf.cdo.tests.model3/src/org/eclipse/emf/cdo/tests/model3/Model3Package.java
@@ -123,12 +123,12 @@ public interface Model3Package extends EPackage
int POLYGON = 2;
/**
* The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
* @ordered
*/
- int POLYGON__POINT = 0;
+ int POLYGON__POINTS = 0;
/**
* The number of structural features of the '<em>Polygon</em>' class. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
EClass getPolygon();
/**
* Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoint
* <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @return the meta object for the attribute list '<em>Point</em>'.
* @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoint()
* @see #getPolygon()
* @generated
*/
- EAttribute getPolygon_Point();
+ EAttribute getPolygon_Points();
/**
* Returns the meta object for data type '{@link org.eclipse.emf.cdo.tests.model3.Point <em>Point</em>}'. <!--
@@ -290,12 +290,12 @@ public interface Model3Package extends EPackage
EClass POLYGON = eINSTANCE.getPolygon();
/**
* The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*
* @generated
*/
- EAttribute POLYGON__POINT = eINSTANCE.getPolygon_Point();
+ EAttribute POLYGON__POINTS = eINSTANCE.getPolygon_Points();
/**
* The meta object literal for the '<em>Point</em>' data type. <!-- begin-user-doc --> <!-- end-user-doc -->
@@ -123,12 +123,12 @@ public interface Model3Package extends EPackage
int POLYGON = 2;
/**
- * The feature id for the '<em><b>Point</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * The feature id for the '<em><b>Points</b></em>' attribute list. <!-- begin-user-doc --> <!-- end-user-doc -->
*
* @generated
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
EClass getPolygon();
/**
- * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoint
- * <em>Point</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
+ * Returns the meta object for the attribute list '{@link org.eclipse.emf.cdo.tests.model3.Polygon#getPoints
+ * <em>Points</em>}'. <!-- begin-user-doc --> <!-- end-user-doc -->
*
@@ -200,15 +200,15 @@ public interface Model3Package extends EPackage
*
- * @return the meta object for the attribute list '<em>Point</em>'.
- * @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoint()
+ * @return the meta object for the attribute list '<em>Points</em>'.
+ * @see org.eclipse.emf.cdo.tests.model3.Polygon#getPoints()
* @see #getPolygon()
* @generated
@@ -290,12 +290,12 @@ public interface Model3Package extends EPackage
EClass POLYGON = eINSTANCE.getPolygon();
/**
- * The meta object literal for the '<em><b>Point</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
+ * The meta object literal for the '<em><b>Points</b></em>' attribute list feature. <!-- begin-user-doc --> <!--
* end-user-doc -->
*

Back to the top